pygeodesy.geod3solve.GeodesicLine3Solve

Package pygeodesy :: Module geod3solve :: Class GeodesicLine3Solve |
[frames] | no frames]

# Class GeodesicLine3Solve

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
    solveBase._SolveCapsBase --+
                               |
            solveBase._SolveBase --+
                                   |
               solveBase._Solve3Base --+
                                       |
                     _Geodesic3SolveBase --+
                                           |
                                          GeodesicLine3Solve

Wrapper to invoke Karney's Geod3Solve as a `triaxial` version of Karney's Python class GeodesicLine.

Notes:

- Use property `GeodSolve` or env variable `PYGEODESY_GEODSOLVE` to specify the (fully qualified) path to the `GeodSolve` executable.
- This `geodesic` is intended for testing purposes only, it invokes the `GeodSolve` executable for every method call.

Instance Methods
__init__(self, geodesic3, bet1, omg1, alp1, caps=32671, **unit_name) New GeodesicLine3Solve instance, allowing points to be found along a geodesic starting at `(bet1, omg1)` with azimuth `alp1`. |
Intersecant2(self, bet0, omg0, radius, **kwds) Not implemented, throws a `NotImplementedError` always. |
PlumbTo(self, bet0, omg0, **kwds) Not implemented, throws a `NotImplementedError` always. |
Position(self, s12, outmask=32671) Find the position on the line given `s12`. |
toStr(self, **prec_sep_other) Return this `GeodesicLine3Solve` as string. |
Inherited from `solveBase._SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `_Geodesic3SolveBase`: `datum`, `ellipsoid`, `f`, `flattening` Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| alp1 Get the azimuth at the first point (compass `degrees`).
| bet1 Get the ellipsoidal latitude of the first point (`degrees`).
| geodesic3 Get the `triaxial` geodesic (Geodesic3Solve).
| omg1 Get the ellipsoidal longitude of the first point (`degrees`).
| triaxial3 Get the triaxial (`Triaxial3`).
Inherited from `_Geodesic3SolveBase`: `Geod3Solve`, `a`, `b`, `c` Inherited from `solveBase._SolveBase`: `reverse2`, `unroll` Inherited from `solveBase._SolveCapsBase`: `Exact`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, geodesic3, bet1, omg1, alp1, caps=32671, **unit_name) (Constructor) |
New GeodesicLine3Solve instance, allowing points to be found along a geodesic starting at `(bet1, omg1)` with azimuth `alp1`. Arguments: `geodesic3` - The geodesic to use (Geodesic3Solve). `bet1` - Ellipsoidal latitude of the first point (`Ang` or `unit`). `omg1` - Ellipsoidal longitude of the first point (`Ang` or `unit`). `alp1` - Azimuth at the first point (compass `degrees`, `Ang` or `unit`). `caps` - Bit-or'ed combination of Caps values specifying the capabilities the GeodesicLine3Solve instance should possess, `caps=Caps.ALL` always. Include `Caps.LINE_OFF` if updates to the `geodesic3` should not be reflected in this GeodesicLine3Solve instance. `unit_name` - Optional `name=NN` (`str`) and scalar `unit=`Degrees (or Degrees). Raises: `Geodesic3Error` - Invalid path for the `Geod3Solve` executable or isn't the `Geod3Solve` executable, see property `geodesic3.Geod3Solve`. `TypeError` - Invalid `geodesic3`. Overrides: object.__init__

### Position (self, s12, outmask=32671) |
Find the position on the line given `s12`. Arguments: `s12` - Distance from the first point to the second (`meter`). Returns: A `GDict` with 7 items `bet1, omg1, alp1, bet2, omg2, alp2, s12`.

### toStr (self, **prec_sep_other) |
Return this `GeodesicLine3Solve` as string. Arguments: `prec_sep` - See toStr. Returns: GeodesicLine3Solve items (`str`). Overrides: named._Named.toStr

Property Details

### alp1 Get the azimuth at the first point (compass `degrees`). Get method: alp1(self) - Get the azimuth at the first point (compass `degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### bet1 Get the ellipsoidal latitude of the first point (`degrees`). Get method: bet1(self) - Get the ellipsoidal latitude of the first point (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesic3 Get the `triaxial` geodesic (Geodesic3Solve). Get method: geodesic3(self) - Get the `triaxial` geodesic (Geodesic3Solve). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### omg1 Get the ellipsoidal longitude of the first point (`degrees`). Get method: omg1(self) - Get the ellipsoidal longitude of the first point (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### triaxial3 Get the triaxial (`Triaxial3`). Get method: triaxial3(self) - Get the triaxial (`Triaxial3`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.